#ifndef LIB_MSG_H
#define LIB_MSG_H

/* Beginning of labels */
#define TMSG_LIB_X11_ERR		0
#define TMSG_LIB_CONFIRM		1
#define TMSG_MISSING_ALPHABET		2
#define TMSG_OLD_VIEW_NOT_REPLACED		3
#define TMSG_OLD_SCH_TO_RECOMP		4
#define TMSG_MISSING_FONT		5
#define TMSG_NO_MEMORY		6
#define TMSG_UNABLE_TO_CONNECT_TO_X		7
#define TMSG_VIEW_MODIFIED_BEFORE_CREATION		8
#define TMSG_LIB_RULES_TABLE_FULL		9
#define TMSG_INCORRECT_STR_FILE		10
#define TMSG_INCORRECT_PRS_FILE		11
#define TMSG_DOC_PRINTED		12
#define TMSG_REDUCTION		13
#define TMSG_1_PAGE_SHEET		14
#define TMSG_2_PAGE_SHEET		15
#define TMSG_4_PAGE_SHEET		16
#define TMSG_LIB_STRING		17
#define TMSG_NOT_ENOUGH_MEMORY		18
#define TMSG_DEBUG_ERROR		19
#define TMSG_DEBUG_SAV_FILES		20
#define TMSG_TRA_FILE_INCORRECT		21
#define TMSG_INVALID_SIBLING		22
#define TMSG_INVALID_CHILD		23
#define TMSG_PAGE		24
#define TMSG_LANGUAGE		25
#define TMSG_ATTR		26
#define TMSG_STD_PRES		27
#define TMSG_APPLY		28
#define TMSG_CHAR		29
#define TMSG_LINE		30
#define TMSG_GRAPHICS_PRES		31
#define TMSG_FORMAT		32
#define TMSG_UNCHANGED		33
#define TMSG_ALIGN		34
#define TMSG_INDENT		35
#define TMSG_LIB_PRINT		36
#define TMSG_MANUAL_FEED		37
#define TMSG_OPTIONS		38
#define TMSG_A4		39
#define TMSG_US		40
#define TMSG_PAPER_SIZE		41
#define TMSG_DONE		42
#define TMSG_DOC_DIR		43
#define TMSG_FILE_EXIST		44
#define TMSG_BUTTON_1		45
#define TMSG_BUTTON_2		46
#define TMSG_FONT_FAMILY		47
#define TMSG_ROMAN		48
#define TMSG_BOLD		49
#define TMSG_ITALIC		50
#define TMSG_OBLIQUE		51
#define TMSG_NOT_BOLD		52
#define TMSG_BOLDNESS		53
#define TMSG_NORMAL		54
#define TMSG_UNDERLINE		55
#define TMSG_CROSS_OUT		56
#define TMSG_BODY_SIZE_PTS		57
#define TMSG_INDENT_PTS		58
#define TMSG_LINE_SPACING_PTS		59
#define TMSG_LINE_SPACING		60
#define TMSG_SAVE_DOC		61
#define TMSG_CLOSE_DON_T_SAVE		62
#define TMSG_STYLE		63
#define TMSG_COLORS		64
#define TMSG_DEL		65
#define TMSG_OUTPUT		66
#define TMSG_PS_FILE		67
#define TMSG_PRINTER		68
#define TMSG_SEARCH_FOR		69
#define TMSG_UPPERCASE_EQ_LOWERCASE		70
#define TMSG_REPLACE_BY		71
#define TMSG_REPLACE		72
#define TMSG_NO_REPLACE		73
#define TMSG_REPLACE_ON_REQU		74
#define TMSG_AUTO_REPLACE		75
#define TMSG_SEARCH_WHERE		76
#define TMSG_BEFORE_SEL		77
#define TMSG_WITHIN_SEL		78
#define TMSG_AFTER_SEL		79
#define TMSG_IN_WHOLE_DOC		80
#define TMSG_DO_NOT_REPLACE		81
#define TMSG_STD_COLORS		82
#define TMSG_BEFORE_CLOSING		83
#define TMSG_CLOSE_DOC		84
#define TMSG_MATH_SYMBOLS		85
#define TMSG_GRAPHICS		86
#define TMSG_LATIN_ALPHABET		87
#define TMSG_GREEK_ALPHABET		88
#define TMSG_SAVE		89
#define TMSG_TEXT		90
#define TMSG_GRAPHIC		91
#define TMSG_SYMBOL		92
#define TMSG_PICTURE		93
#define TMSG_EL_TYPE		94
#define TMSG_AFTER		95
#define TMSG_BEFORE		96
#define TMSG_AROUND		97
#define TMSG_INCLUDE		98
#define TMSG_PASTE		99
#define TMSG_TO_CREATE		100
#define TMSG_INSERT		101
#define TMSG_PAGE_BRK		102
#define TMSG_LANG_OF_EL		103
#define TMSG_INHERITED_LANG		104
#define TMSG_NOT_FOUND		105
#define TMSG_SEARCH_IN		106
#define TMSG_SEARCH		107
#define TMSG_EL_RO		108
#define TMSG_NOTHING_TO_REPLACE		109
#define TMSG_STD_CHAR		110
#define TMSG_STD_GRAPHICS		111
#define TMSG_STD_FORMAT		112
#define TMSG_STD_GEOMETRY		113
#define TMSG_TYPOGRAPHIC_POINTS		114
#define TMSG_LINE_STYLE		115
#define TMSG_LINE_WEIGHT		116
#define TMSG_FILL_PATTERN		117
#define TMSG_SPLIT		118
#define TMSG_OBJECT_TYPE		119
#define TMSG_GOTO_PAGE		120
#define TMSG_ANY		121
#define TMSG_ATTR_TO_SEARCH		122
#define TMSG_TYPE_TO_SEARCH		123
#define TMSG_NATURES		124
#define TMSG_VALUE_OF_ATTR		125
#define TMSG_UNKNOWN_ATTR		126
#define TMSG_CANCEL		127
#define TMSG_ERROR_PS_TRANSLATION		128
#define TMSG_UNKNOWN_PRINTER		129
#define TMSG_CANNOT_CREATE_PS		130
#define TMSG_OVERLINE		131
#define TMSG_DOCUMENT_FORMAT		132
#define TMSG_EVENTS		133
#define TMSG_DEL_ATTR		134
#define TMSG_CPBUTTON_1		135
#define TMSG_CPBUTTON_2		136
#define TMSG_CPMOREBUTTON		137
#define TMSG_CPGETBUTTON		138
#define TMSG_CPCOLORBUTTON		139
#define TMSG_LIB_MSG_MAX		140

#endif
